==> ulyxex.0.0.6.with-tinyMce.zip: pages/code/admin_user_add.php <==
<?php
class UserAdd extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function add_user() {
		/* check is login is in use */
		$query = "SELECT ID FROM ".USERS." WHERE LOGIN = '".$this->h->safe($_POST['userlogin'])."'";
		$query = $this->q($query);
		if (@mysql_fetch_assoc($query)) return $this->h->h3("login in use !");
		/* create user */
		if (empty($_POST['password'])) {
			$result = $this->h->h3($this->tr->w("password empty !"));
		} else if ($_POST['password'] != $_POST['confirm'] || $this->h->num($_POST['level']) < $_SESSION['level']) {
			$result = $this->h->h3($this->tr->w("wrong password or level !"));
		} else if ($_POST['userlogin'] == "") {
			$result = $this->h->h3($this->tr->w("login field empty !"));
		} else if ($_POST['username'] == "") {
			$result = $this->h->h3($this->tr->w("username field empty !"));
		} else {
			$query = "INSERT INTO ".USERS."  (LOGIN,PASSWORD,USERNAME,MAIL,DESCRIPTION,USERLEVEL,USEROWNER) VALUES (".
											"'".$this->h->safe($_POST['userlogin'])."','".$this->h->crypt($_POST['password'])."','".
											$this->h->safe($_POST['username'])."','".$this->h->safe($_POST['mail'])."','".
											$this->h->safe($_POST['description'])."',".$this->h->num($_POST['level']).",".
											$_SESSION['userid'].")";
			$query = $this->q($query);
			$result = $this->h->h3($this->tr->ws("user").strip_tags($_POST['username']).$this->tr->wsp("created !"));
		}
		return $result;
	}
	public function add_user_form() {
		$content = $this->h->input("hidden","add",1);
		$content .= $this->h->p($this->tr->ws("login").$this->h->input("text","userlogin"));
		$content .= $this->h->p($this->tr->ws("password").$this->h->input("password","password"));
		$content .= $this->h->p($this->tr->ws("confirm password").$this->h->input("password","confirm"));
		$levels = array();
		$scaleLevel = 4;
		if ($_SESSION['userid'] == 1) $scaleLevel = 5;
		for ($i=0;$i < ($scaleLevel - $_SESSION['level']);$i++) {
			$x = 4 - $i;
			$levels["level ".$x] =  $x;
		}
		$content .= $this->h->p($this->tr->ws("level").$this->h->select($levels,"level"));
		$content .= $this->h->p($this->tr->ws("name")).$this->h->p($this->h->input("text","username"));
		$content .= $this->h->p($this->tr->w("description")).$this->h->p($this->h->textarea("","description",array(8,FIELDWIDTH)));
		$content .= $this->h->p($this->tr->ws("mail").$this->h->input("text","mail"));
		$content .= $this->h->p($this->h->input("submit","save",$this->tr->w("save")));
		$result = $this->h->form($content,"user","post","admin.php?action=add_user");
		return $result;
	}
}
?>

==> ulyxex.0.0.7.with-tinyMce.zip: pages/code/admin_user_add.php <==
<?php
class UserAdd extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function add_user() {
		/* check if login is in use */
		$query = "SELECT ID FROM ".USERS." WHERE LOGIN = '".$this->h->safe($_POST['userlogin'])."'";
		$query = $this->q($query);
		if (@mysql_fetch_assoc($query)) return $this->h->h3($this->tr->w("login in use !"));
		/* create user */
		if (empty($_POST['password'])) {
			$result = $this->h->h3($this->tr->w("password empty !"));
		} else if ($_POST['password'] != $_POST['confirm'] || $this->h->num($_POST['level']) < $_SESSION['level']) {
			$result = $this->h->h3($this->tr->w("wrong password or level !"));
		} else if ($_POST['userlogin'] == "") {
			$result = $this->h->h3($this->tr->w("login field empty !"));
		} else if ($_POST['username'] == "") {
			$result = $this->h->h3($this->tr->w("username field empty !"));
		} else {
			$query = "INSERT INTO ".USERS."  (LOGIN,PASSWORD,USERNAME,MAIL,DESCRIPTION,USERLEVEL,USEROWNER) VALUES (".
											"'".$this->h->safe($_POST['userlogin'])."','".$this->h->crypt($_POST['password'])."','".
											$this->h->safe($_POST['username'])."','".$this->h->safe($_POST['mail'])."','".
											$this->h->safe($_POST['description'])."',".$this->h->num($_POST['level']).",".
											$_SESSION['userid'].")";
			$query = $this->q($query);
			$result = $this->h->h3($this->tr->ws("user").strip_tags($_POST['username']).$this->tr->wsp("created !"));
		}
		return $result;
	}
	public function add_user_form() {
		$content = $this->h->input("hidden","add",1);
		$content .= $this->h->p($this->tr->ws("login").$this->h->input("text","userlogin"));
		$content .= $this->h->p($this->tr->ws("password").$this->h->input("password","password"));
		$content .= $this->h->p($this->tr->ws("confirm password").$this->h->input("password","confirm"));
		$levels = array();
		$scaleLevel = 4;
		if ($_SESSION['userid'] == 1) $scaleLevel = 5;
		for ($i=0;$i < ($scaleLevel - $_SESSION['level']);$i++) {
			$x = 4 - $i;
			$levels["level ".$x] =  $x;
		}
		$content .= $this->h->p($this->tr->ws("level").$this->h->select($levels,"level"));
		$content .= $this->h->p($this->tr->ws("name")).$this->h->p($this->h->input("text","username"));
		$content .= $this->h->p($this->tr->w("description")).$this->h->p($this->h->textarea("","description",array(8,FIELDWIDTH)));
		$content .= $this->h->p($this->tr->ws("mail").$this->h->input("text","mail"));
		$content .= $this->h->p($this->h->input("submit","save",$this->tr->w("save")));
		$result = $this->h->form($content,"user","post","admin.php?action=add_user");
		return $result;
	}
}
?>
